==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/zh_TW.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "已加入信任伺服器清單",
    "No server found with ID: %s" : "沒有找到此 ID 的伺服器：%s",
    "Could not remove server" : "無法移除伺服器",
    "Server is already in the list of trusted servers." : "伺服器已在信任清單內。",
    "No server to federate with found" : "沒有找到可聯邦的伺服器",
    "Could not add server" : "無法新增伺服器",
    "Trusted servers" : "信任的伺服器",
    "Federation" : "聯邦",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "聯盟功能允許您與信任的伺服器連結，交換帳號列表。",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "聯盟功能允許您與信任的伺服器連結，交換帳號列表。舉例來說，與其他雲端聯盟的使用者分享檔案時，有了這一份列表，就可以在輸入框搜尋他們的帳號名稱。",
    "External documentation for Federated Cloud Sharing" : "聯邦雲端分享的外部文件",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "聯盟功能允許您與信任的伺服器連結，交換使用者列表。舉例來說，與其他雲端聯盟的帳號分享檔案時，有了這一份列表，就可以在輸入框搜尋他們的帳號名稱。不必將伺服器新增為受信任的伺服器就可以建立聯盟分享。",
    "Each server must validate the other. This process may require a few cron cycles." : "每個伺服器都必須驗證其他伺服器。這個過程可能需要幾個 cron 循環。",
    "+ Add trusted server" : "+ 新增信任的伺服器",
    "Trusted server" : "信任的伺服器",
    "Add" : "新增"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/zh_TW.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "已加入信任伺服器清單",
    "No server found with ID: %s" : "沒有找到此 ID 的伺服器：%s",
    "Could not remove server" : "無法移除伺服器",
    "Server is already in the list of trusted servers." : "伺服器已在信任清單內。",
    "No server to federate with found" : "沒有找到可聯邦的伺服器",
    "Could not add server" : "無法新增伺服器",
    "Trusted servers" : "信任的伺服器",
    "Federation" : "聯邦",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "聯盟功能允許您與信任的伺服器連結，交換帳號列表。",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "聯盟功能允許您與信任的伺服器連結，交換帳號列表。舉例來說，與其他雲端聯盟的使用者分享檔案時，有了這一份列表，就可以在輸入框搜尋他們的帳號名稱。",
    "Could not add trusted server. Please try again later." : "無法新增受信任的伺服器。請稍後再試。",
    "Add trusted server" : "新增受信任的伺服器",
    "Server url" : "伺服器 URL",
    "Add" : "新增",
    "Server ok" : "伺服器 OK",
    "User list was exchanged at least once successfully with the remote server." : "使用者清單已至少成功與遠端伺服器交換一次。",
    "Server pending" : "伺服器擱置中",
    "Waiting for shared secret or initial user list exchange." : "等待共享祕密或初始使用者清單交換。",
    "Server access revoked" : "伺服器存取權限已撤銷",
    "Server failure" : "伺服器故障",
    "Connection to the remote server failed or the remote server is misconfigured." : "連線至遠端伺服器失敗，或遠端伺服器設定錯誤。",
    "Failed to delete trusted server. Please try again later." : "無法刪除受信任伺服器。請稍後再試。",
    "Delete" : "刪除",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "聯盟功能允許您與信任的伺服器連結，交換使用者列表。舉例來說，與其他雲端聯盟的帳號分享檔案時，有了這一份列表，就可以在輸入框搜尋他們的帳號名稱。不必將伺服器新增為受信任的伺服器就可以建立聯盟分享。",
    "Each server must validate the other. This process may require a few cron cycles." : "每個伺服器都必須驗證其他伺服器。這個過程可能需要幾個 cron 循環。",
    "External documentation for Federated Cloud Sharing" : "聯邦雲端分享的外部文件",
    "+ Add trusted server" : "+ 新增信任的伺服器",
    "Trusted server" : "信任的伺服器"
},
"nplurals=1; plural=0;");
